You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by ak...@apache.org on 2004/09/05 09:28:54 UTC

svn commit: rev 43377 - in incubator/directory/seda/trunk/api/src/java/org/apache/seda: decoder listener

Author: akarasulu
Date: Sun Sep  5 00:28:54 2004
New Revision: 43377

Added:
   incubator/directory/seda/trunk/api/src/java/org/apache/seda/listener/InetServiceListenerConfig.java
      - copied, changed from rev 43375, incubator/directory/seda/trunk/api/src/java/org/apache/seda/listener/ServerListener.java
Removed:
   incubator/directory/seda/trunk/api/src/java/org/apache/seda/listener/ServerListener.java
Modified:
   incubator/directory/seda/trunk/api/src/java/org/apache/seda/decoder/ClientDecoder.java
   incubator/directory/seda/trunk/api/src/java/org/apache/seda/listener/ListenerManager.java
   incubator/directory/seda/trunk/api/src/java/org/apache/seda/listener/ListenerManagerMonitor.java
Log:
renamed ServerListener->InetServiceListenerConfig

Modified: incubator/directory/seda/trunk/api/src/java/org/apache/seda/decoder/ClientDecoder.java
==============================================================================
--- incubator/directory/seda/trunk/api/src/java/org/apache/seda/decoder/ClientDecoder.java	(original)
+++ incubator/directory/seda/trunk/api/src/java/org/apache/seda/decoder/ClientDecoder.java	Sun Sep  5 00:28:54 2004
@@ -23,7 +23,6 @@
 import org.apache.commons.codec.stateful.DecoderCallback;
 
 import org.apache.seda.listener.ClientKey;
-import org.apache.seda.listener.ClientKey;
 
 
 /**

Copied: incubator/directory/seda/trunk/api/src/java/org/apache/seda/listener/InetServiceListenerConfig.java (from rev 43375, incubator/directory/seda/trunk/api/src/java/org/apache/seda/listener/ServerListener.java)
==============================================================================
--- incubator/directory/seda/trunk/api/src/java/org/apache/seda/listener/ServerListener.java	(original)
+++ incubator/directory/seda/trunk/api/src/java/org/apache/seda/listener/InetServiceListenerConfig.java	Sun Sep  5 00:28:54 2004
@@ -27,17 +27,17 @@
  * @author $Author$
  * @version $Rev$
  */
-public interface ServerListener
+public interface InetServiceListenerConfig
 {
     /**
      * Gets the server socket backlog for this ServerListener
      *
      * @return client connection backlog
      */
     public int getBacklog() ;
 
     /**
      * Gets the ip interface address this ServerListener listens on.
      *
      * @return the ip address octets i.e. { 127,0,0,1 } for 127.0.0.1
      */
@@ -51,7 +51,7 @@
     public boolean isSecure() ;
     
     /**
      * Gets the URL for this ServerListener using the specified ip address and 
      * the tcp port number listened to.  The ipaddress is resolved to a host 
      * name.
      *
@@ -60,7 +60,7 @@
     public String getURL() ;
 
     /**
      * Gets the InetServiceEntry associated with this ServerListener.
      *
      * @return the service entry for this listener
      */
@@ -27,17 +27,17 @@
 {
     /**
-     * Gets the server socket backlog for this ServerListener
+     * Gets the server socket backlog for this InetServiceListenerConfig
      *
      * @return client connection backlog
@@ -27,17 +27,17 @@
 
     /**
-     * Gets the ip interface address this ServerListener listens on.
+     * Gets the ip interface address this InetServiceListenerConfig listens on.
      *
      * @return the ip address octets i.e. { 127,0,0,1 } for 127.0.0.1
@@ -51,7 +51,7 @@
     
     /**
-     * Gets the URL for this ServerListener using the specified ip address and 
+     * Gets the URL for this InetServiceListenerConfig using the specified ip address and
      * the tcp port number listened to.  The ipaddress is resolved to a host 
      * name.
@@ -60,7 +60,7 @@
 
     /**
-     * Gets the InetServiceEntry associated with this ServerListener.
+     * Gets the InetServiceEntry associated with this InetServiceListenerConfig.
      *
      * @return the service entry for this listener

Modified: incubator/directory/seda/trunk/api/src/java/org/apache/seda/listener/ListenerManager.java
==============================================================================
--- incubator/directory/seda/trunk/api/src/java/org/apache/seda/listener/ListenerManager.java	(original)
+++ incubator/directory/seda/trunk/api/src/java/org/apache/seda/listener/ListenerManager.java	Sun Sep  5 00:28:54 2004
@@ -35,15 +35,15 @@
     /**
      * Binds and registers a server listener.
      * 
      * @param a_listener the listener to register and bind
      */
-    public void bind( ServerListener a_listener ) throws IOException ;
+    public void bind( InetServiceListenerConfig a_listenerConfig ) throws IOException ;
     
     /**
      * Unbinds and unregisters a server listener.
      * 
      * @param a_listener the listener to unregister and unbind
      * @throws IOException if there is a problem unbinding a listener
      */
-    public void unbind( ServerListener a_listener ) throws IOException ;
+    public void unbind( InetServiceListenerConfig a_listenerConfig ) throws IOException ;
 }
@@ -35,15 +35,15 @@
      * Binds and registers a server listener.
      * 
-     * @param a_listener the listener to register and bind
+     * @param a_listenerConfig the listener to register and bind
      */
@@ -35,15 +35,15 @@
      * Unbinds and unregisters a server listener.
      * 
-     * @param a_listener the listener to unregister and unbind
+     * @param a_listenerConfig the listener to unregister and unbind
      * @throws IOException if there is a problem unbinding a listener
      */

Modified: incubator/directory/seda/trunk/api/src/java/org/apache/seda/listener/ListenerManagerMonitor.java
==============================================================================
--- incubator/directory/seda/trunk/api/src/java/org/apache/seda/listener/ListenerManagerMonitor.java	(original)
+++ incubator/directory/seda/trunk/api/src/java/org/apache/seda/listener/ListenerManagerMonitor.java	Sun Sep  5 00:28:54 2004
@@ -49,16 +49,16 @@
     /**
      * Monitors bind occurences.
      * 
      * @param a_listener the listener just bound to a port
      */
-    void bindOccured( ServerListener a_listener ) ;
+    void bindOccured( InetServiceListenerConfig a_listenerConfig ) ;
     
     /**
      * Monitors unbind occurences.
      * 
      * @param a_listener the listener just unbound from a port
      */
-    void unbindOccured( ServerListener a_listener ) ;
+    void unbindOccured( InetServiceListenerConfig a_listenerConfig ) ;
     
     /**
      * Monitors the occurrence of successful socket accept attempts
@@ -84,18 +84,18 @@
     /**
      * Monitors bind failures.
      * 
      * @param a_listener the listener whose bind attempt failed
      * @param a_failure the exception resulting from the failure
      */
-    void failedToBind( ServerListener a_listener, IOException a_failure ) ;
+    void failedToBind( InetServiceListenerConfig a_listenerConfig, IOException a_failure ) ;
     
     /**
      * Monitors unbind failures.
      * 
      * @param a_listener the listener whose unbind attempt failed
      * @param a_failure the exception resulting from the failure
      */
-    void failedToUnbind( ServerListener a_listener, IOException a_failure ) ;
+    void failedToUnbind( InetServiceListenerConfig a_listenerConfig, IOException a_failure ) ;
     
     /**
      * Monitors expiration failures on client keys.
@@ -49,16 +49,16 @@
      * Monitors bind occurences.
      * 
-     * @param a_listener the listener just bound to a port
+     * @param a_listenerConfig the listener just bound to a port
      */
@@ -49,16 +49,16 @@
      * Monitors unbind occurences.
      * 
-     * @param a_listener the listener just unbound from a port
+     * @param a_listenerConfig the listener just unbound from a port
      */
@@ -84,18 +84,18 @@
      * Monitors bind failures.
      * 
-     * @param a_listener the listener whose bind attempt failed
+     * @param a_listenerConfig the listener whose bind attempt failed
      * @param a_failure the exception resulting from the failure
      */
@@ -84,18 +84,18 @@
      * Monitors unbind failures.
      * 
-     * @param a_listener the listener whose unbind attempt failed
+     * @param a_listenerConfig the listener whose unbind attempt failed
      * @param a_failure the exception resulting from the failure
      */